@@ -6,11 +6,11 @@ WWW::Mechanize - Handy web browsing in a Perl object
 
 =head1 VERSION
 
-Version 1.31_02
+Version 1.49_01
 
 =cut
 
-our $VERSION = '1.31_02';
+our $VERSION = '1.49_01';
 
 =head1 SYNOPSIS
 
@@ -81,6 +81,12 @@ FAQ in WWW::Mechanize::FAQ for more.
 
 =over 4
 
+=item * L<http://code.google.com/p/www-mechanize/issues/list>
+
+The queue for bugs & enhancements in WWW::Mechanize and
+Test::WWW::Mechanize.  Please note that the queue at L<http://rt.cpan.org>
+is no longer maintained.
+
 =item * L<http://search.cpan.org/dist/WWW-Mechanize/>
 
 The CPAN documentation page for Mechanize.
@@ -89,11 +95,6 @@ The CPAN documentation page for Mechanize.
 
 Frequently asked questions.  Make sure you read here FIRST.
 
-=item * L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Mechanize>
-
-The RT queue for bugs & enhancements in Mechanize.  Click the "Report bug"
-link if your bug isn't already reported.
-
 =back
 
 =cut
@@ -105,6 +106,7 @@ use HTTP::Request 1.30;
 use LWP::UserAgent 2.003;
 use HTML::Form 1.00;
 use HTML::TokeParser;
+use HTTP::Response::Encoding 0.05;
 
 use base 'LWP::UserAgent';
 
@@ -147,7 +149,15 @@ parms that L<LWP::UserAgent> recognizes.
 
 Checks each request made to see if it was successful.  This saves you
 the trouble of manually checking yourself.  Any errors found are errors,
-not warnings.  Default is off.
+not warnings.  Default is ON.
+
+=item * C<< noproxy => [0|1] >>
+
+Turn off the automatic call to the L<LWP::UserAgent> C<env_proxy> function.
+
+This needs to be explicitly turned off if you're using L<Crypt::SSLeay> to
+access a https site via a proxy server.  Note: you still need to set your
+HTTPS_PROXY environment variable as appropriate.
 
 =item * C<< onwarn => \&func >>
 
@@ -194,7 +204,7 @@ sub new {
     );
 
     my %mech_parms = (
-        autocheck   => 0,
+        autocheck   => 1,
         onwarn      => \&WWW::Mechanize::_warn,
         onerror     => \&WWW::Mechanize::_die,
         quiet       => 0,
@@ -222,7 +232,7 @@ sub new {
         $self->{$parm} = $mech_parms{$parm};
     }
     $self->{page_stack} = [];
-    $self->env_proxy();
+    $self->env_proxy() unless $parent_parms{noproxy};
 
     # libwww-perl 5.800 (and before, I assume) has a problem where
     # $ua->{proxy} can be undef and clone() doesn't handle it.
@@ -324,8 +334,8 @@ I<$uri> can be a well-formed URL string, a L<URI> object, or a
 L<WWW::Mechanize::Link> object.
 
 The results are stored internally in the agent object, but you don't
-know that.  Just use the accessors listed below.  Poking at the internals
-is deprecated and subject to change in the future.
+know that.  Just use the accessors listed below.  Poking at the
+internals is deprecated and subject to change in the future.
 
 C<get()> is a well-behaved overloaded version of the method in
 L<LWP::UserAgent>.  This lets you do things like
@@ -335,6 +345,10 @@ L<LWP::UserAgent>.  This lets you do things like
 and you can rest assured that the parms will get filtered down
 appropriately.
 
+B<NOTE:> Because C<:content_file> causes the page contents to be
+stored in a file instead of the response object, some Mech functions
+that expect it to be there won't work as expected. Use with caution.
+
 =cut
 
 sub get {
@@ -387,7 +401,7 @@ sub _SUPER_put {
 =head2 $mech->reload()
 
 Acts like the reload button in a browser: repeats the current
-request. The history (as per the L<back> method) is not altered.
+request. The history (as per the L</back> method) is not altered.
 
 Returns the L<HTTP::Response> object from the reload, or C<undef>
 if there's no current request.
@@ -551,32 +565,59 @@ sub content {
 
     if ( $self->is_html ) {
         my %parms = @_;
+
         if ( exists $parms{base_href} ) {
-            my $arg = (delete $parms{base_href}) || $self->base;
-            $content=~s/<head>/<head>\n<base href="$arg">/i;
+            my $base_href = (delete $parms{base_href}) || $self->base;
+            $content=~s/<head>/<head>\n<base href="$base_href">/i;
         }
-        if ( my $arg = delete $parms{format} ) {
-            if ($arg eq 'text') {
-                require HTML::TreeBuilder;
-                my $tree = HTML::TreeBuilder->new();
-                $tree->parse($content);
-                $tree->eof();
-                $tree->elementify(); # just for safety
-                $content = $tree->as_text();
-                $tree->delete;
-            }
-            else {
-                $self->die( qq{Unknown "format" parameter "$arg"} );
-            }
+
+        if ( my $format = delete $parms{format} ) {
+            $content = $self->_format_content( $format, $content );
         }
-        for my $cmd ( sort keys %parms ) {
-            $self->die( qq{Unknown named argument "$cmd"} );
-        }
-    } # is HTML
+
+        $self->_check_unhandled_parms( %parms );
+    }
 
     return $content;
 }
 
+sub _format_content {
+    my $self = shift;
+    my $format = shift;
+    my $content = shift;
+
+    if ( $format eq 'text' ) {
+        return $self->_content_as_text($content);
+    }
+    else {
+        $self->die( qq{Unknown "format" parameter "$format"} );
+    }
+}
+
+sub _content_as_text {
+    my $self = shift;
+    my $content = shift;
+
+    require HTML::TreeBuilder;
+    my $tree = HTML::TreeBuilder->new();
+    $tree->parse($content);
+    $tree->eof();
+    $tree->elementify(); # just for safety
+    my $formatted_content = $tree->as_text();
+    $tree->delete;
+
+    return $formatted_content;
+}
+
+sub _check_unhandled_parms {
+    my $self  = shift;
+    my %parms = @_;
+
+    for my $cmd ( sort keys %parms ) {
+        $self->die( qq{Unknown named argument "$cmd"} );
+    }
+}
+
 =head1 LINK METHODS
 
 =head2 $mech->links
@@ -853,7 +894,7 @@ sub _clean_keys {
 =head2 $mech->find_all_links( ... )
 
 Returns all the links on the current page that match the criteria.  The
-method for specifying link criteria is the same as in C<L<find_link()>>.
+method for specifying link criteria is the same as in C<L</find_link()>>.
 Each of the links returned is a L<WWW::Mechanize::Link> object.
 
 In list context, C<find_all_links()> returns a list of the links.
@@ -1081,7 +1122,7 @@ sub _match_any_image_parms {
 =head2 $mech->find_all_images( ... )
 
 Returns all the images on the current page that match the criteria.  The
-method for specifying image criteria is the same as in C<L<find_image()>>.
+method for specifying image criteria is the same as in C<L</find_image()>>.
 Each of the images returned is a L<WWW::Mechanize::Image> object.
 
 In list context, C<find_all_images()> returns a list of the images.
@@ -1116,11 +1157,11 @@ sub forms {
 =head2 $mech->form_number($number)
 
 Selects the I<number>th form on the page as the target for subsequent
-calls to C<L<field()>> and C<L<click()>>.  Also returns the form that was
+calls to C<L</field()>> and C<L</click()>>.  Also returns the form that was
 selected.
 
 If it is found, the form is returned as an L<HTML::Form> object and set internally
-for later use with Mech's form methods such as C<L<field()>> and C<L<click()>>.
+for later use with Mech's form methods such as C<L</field()>> and C<L</click()>>.
 
 Emits a warning and returns undef if no form is found.
 
@@ -1149,7 +1190,7 @@ with that name, then the first one is used, and a warning is
 generated.
 
 If it is found, the form is returned as an L<HTML::Form> object and set internally
-for later use with Mech's form methods such as C<L<field()>> and C<L<click()>>.
+for later use with Mech's form methods such as C<L</field()>> and C<L</click()>>.
 
 Returns undef if no form is found.
 
@@ -1180,7 +1221,7 @@ is more than one form on the page with that matches, then the first one is used,
 and a warning is generated.
 
 If it is found, the form is returned as an L<HTML::Form> object and set internally
-for later used with Mech's form methods such as C<L<field()>> and C<L<click()>>.
+for later used with Mech's form methods such as C<L</field()>> and C<L</click()>>.
 
 Returns undef if no form is found.
 
@@ -1217,9 +1258,10 @@ sub form_with_fields {
 
 =head2 $mech->field( $name, \@values, $number )
 
-Given the name of a field, set its value to the value specified.  This
-applies to the current form (as set by the L<form_name()> or L<form_number()> method or defaulting
-to the first form on the page).
+Given the name of a field, set its value to the value specified.
+This applies to the current form (as set by the L</form_name()> or
+L</form_number()> method or defaulting to the first form on the
+page).
 
 The optional I<$number> parameter is used to distinguish between two fields
 with the same name.  The fields are numbered from 1.
@@ -1253,7 +1295,8 @@ specified.  If the field is not E<lt>select multipleE<gt> and the
 C<$value> is an array, only the B<first> value will be set.  [Note:
 the documentation previously claimed that only the last value would
 be set, but this was incorrect.]  Passing C<$value> as a hash with
-an C<n> key selects an item by number (e.g. C<{n => 3> or C<{n => [2,4]}>).
+an C<n> key selects an item by number (e.g.
+C<< {n => 3} >> or C<{ {n => [2,4]} >>).
 The numbering starts at 1.  This applies to the current form.
 
 Returns 1 on successfully setting the value. On failure, returns
@@ -1623,6 +1666,8 @@ sub click_button {
 Submits the page, without specifying a button to click.  Actually,
 no button is clicked at all.
 
+Returns an L<HTTP::Response> object.
+
 This used to be a synonym for C<< $mech->click( 'submit' ) >>, but is no
 longer so.
 
@@ -1655,32 +1700,32 @@ and data setting in one operation. It selects the first form that contains all
 fields mentioned in C<\%fields>.  This is nice because you don't need to know
 the name or number of the form to do this.
 
-(calls C<L<form_with_fields>> and C<L<set_fields()>>).
+(calls C<L</form_with_fields()>> and C<L</set_fields()>>).
 
 If you choose this, the form_number, form_name and fields options will be ignored.
 
 =item * form_number => n
 
-Selects the I<n>th form (calls C<L<form_number()>>).  If this parm is not
+Selects the I<n>th form (calls C<L</form_number()>>).  If this parm is not
 specified, the currently-selected form is used.
 
 =item * form_name => name
 
-Selects the form named I<name> (calls C<L<form_name()>>)
+Selects the form named I<name> (calls C<L</form_name()>>)
 
 =item * button => button
 
-Clicks on button I<button> (calls C<L<click()>>)
+Clicks on button I<button> (calls C<L</click()>>)
 
 =item * x => x, y => y
 
-Sets the x or y values for C<L<click()>>
+Sets the x or y values for C<L</click()>>
 
 =back
 
 If no form is selected, the first form found is used.
 
-If I<button> is not passed, then the C<L<submit()>> method is used instead.
+If I<button> is not passed, then the C<L</submit()>> method is used instead.
 
 Returns an L<HTTP::Response> object.
 
@@ -1857,6 +1902,89 @@ sub save_content {
     return;
 }
 
+=head2 $mech->dump_links( [[$fh], $absolute] )
+
+Prints a dump of the links on the current page to I<$fh>.  If I<$fh>
+is not specified or is undef, it dumps to STDOUT.
+
+If I<$absolute> is true, links displayed are absolute, not relative.
+
+=cut
+
+sub dump_links {
+    my $self = shift;
+    my $fh = shift || \*STDOUT;
+    my $absolute = shift;
+
+    for my $link ( $self->links ) {
+        my $url = $absolute ? $link->url_abs : $link->url;
+        $url = '' if not defined $url;
+        print {$fh} $url, "\n";
+    }
+    return;
+}
+
+=head2 $mech->dump_images( [[$fh], $absolute] )
+
+Prints a dump of the images on the current page to I<$fh>.  If I<$fh>
+is not specified or is undef, it dumps to STDOUT.
+
+If I<$absolute> is true, links displayed are absolute, not relative.
+
+=cut
+
+sub dump_images {
+    my $self = shift;
+    my $fh = shift || \*STDOUT;
+    my $absolute = shift;
+
+    for my $image ( $self->images ) {
+        my $url = $absolute ? $image->url_abs : $image->url;
+        $url = '' if not defined $url;
+        print {$fh} $url, "\n";
+    }
+    return;
+}
+
+=head2 $mech->dump_forms( [$fh] )
+
+Prints a dump of the forms on the current page to I<$fh>.  If I<$fh>
+is not specified or is undef, it dumps to STDOUT.
+
+=cut
+
+sub dump_forms {
+    my $self = shift;
+    my $fh = shift || \*STDOUT;
+
+    for my $form ( $self->forms ) {
+        print {$fh} $form->dump, "\n";
+    }
+    return;
+}
+
+=head2 $mech->dump_all( [[$fh], $absolute] )
+
+Prints a dump of all links, images and forms on the current page to
+I<$fh>.  If I<$fh> is not specified or is undef, it dumps to STDOUT.
+
+If I<$absolute> is true, links displayed are absolute, not relative.
+
+=cut
+
+sub dump_all {
+    my $self = shift;
+    my $fh = shift || \*STDOUT;
+    my $absolute = shift;
+
+    $self->dump_links( $fh, $absolute );
+    $self->dump_images( $fh, $absolute );
+    $self->dump_forms( $fh, $absolute );
+
+    return;
+}
+
+
 =head1 OVERRIDDEN LWP::UserAgent METHODS
 
 =head2 $mech->clone()
@@ -2055,10 +2183,8 @@ sub _update_page {
     $self->_reset_page;
 
     # Try to decode the content. Undef will be returned if there's nothing to decompress.
-    # See docs in HTTP::Message for details. Do we need to expose the options there? 
-    # use charset => 'none' because while we want LWP to handle Content-Encoding for 
-    # the auto-gzipping with Compress::Zlib we don't want it messing with charset
-    my $content = $res->decoded_content( charset => 'none' );
+    # See docs in HTTP::Message for details. Do we need to expose the options there?
+    my $content = $res->decoded_content();
     $content = $res->content if (not defined $content);
 
     $content .= _taintedness();
@@ -2429,6 +2555,12 @@ sub _die {
 
 __END__
 
+=head1 REQUESTS & BUGS
+
+The bug queue for WWW::Mechanize and Test::WWW::Mechanize is at
+L<http://code.google.com/p/www-mechanize/issues/list>.  Please do
+not add any tickets to the old queue at L<http://rt.cpan.org/>.
+
 =head1 WWW::MECHANIZE'S SUBVERSION REPOSITORY
 
 Mech and Test::WWW::Mechanize are both hosted at Google Code:
@@ -2468,13 +2600,18 @@ L<http://books.slashdot.org/article.pl?sid=03/12/11/2126256>
 
 =over 4
 
+=item * WWW::Mechanize mailing list
+
+The Mech mailing list is at
+L<http://groups.google.com/group/www-mechanize-users> and is specific
+to Mechanize, unlike the LWP mailing list below.  Although it is a
+users list, all development discussion takes place here, too.
+
 =item * LWP mailing list
 
 The LWP mailing list is at
 L<http://lists.perl.org/showlist.cgi?name=libwww>, and is more
-user-oriented and well-populated than the WWW::Mechanize Development
-list.  This is a good list for Mech users, since LWP is the basis
-for Mech.
+user-oriented and well-populated than the WWW::Mechanize list.
 
 =item * Perlmonks
 
@@ -2578,24 +2715,12 @@ Just like Mech, but using Microsoft Internet Explorer to do the work.
 
 =back
 
-=head1 REQUESTS & BUGS
-
-Please report any requests, suggestions or (gasp!) bugs via the
-excellent RT bug-tracking system at http://rt.cpan.org/, or email to
-C<bug-WWW-Mechanize at rt.cpan.org>.  This makes it much easier for
-me to track things.
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Mechanize> is the RT queue
-for Mechanize.  Please check to see if your bug has already been reported.
-
-Please note that this is NOT for support requests.  Please be sure
-to read the FAQ if you have support requests.
-
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to the numerous people who have helped out on WWW::Mechanize in
 one way or another, including
 Kirrily Robert for the original C<WWW::Automate>,
+Michael Schwern,
 Adriano Ferreira,
 Miyagawa,
 Peteris Krumins,
@@ -2637,7 +2762,7 @@ and the late great Iain Truskett.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2007 Andy Lester. All rights reserved. This program is
+Copyright (c) 2005-2008 Andy Lester. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
